==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPivotKeysDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotKeysDescription } from "./WebPivotKeysDescription";
/**
 * @hidden
 */
export let WebPivotKeysDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotKeysDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotKeysDescriptionMetadata.a == null) {
                WebPivotKeysDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotKeysDescriptionMetadata.c(WebPivotKeysDescriptionMetadata.a);
            }
            if (a.k(WebPivotKeysDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPivotKeysDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotKeys");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Children", "String");
            a.item("Records", "String");
            a.item("Aggregations", "String");
            a.item("Level", "String");
            a.item("ColumnDimensionSeparator", "String");
            a.item("RowDimensionSeparator", "String");
        }
        static d(a) {
            WebPivotKeysDescriptionMetadata.b(a);
            a.ad("WebPivotKeys", () => new WebPivotKeysDescription());
            a.ac("WebPivotKeys", WebPivotKeysDescriptionMetadata.a);
        }
    }
    WebPivotKeysDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPivotKeysDescriptionMetadata, 'WebPivotKeysDescriptionMetadata');
    WebPivotKeysDescriptionMetadata.a = null;
    return WebPivotKeysDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebPivotKeysDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotKeysDescription } from "./WebPivotKeysDescription";
/**
 * @hidden
 */
export let WebPivotKeysDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotKeysDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotKeysDescriptionMetadata.a == null) {
                WebPivotKeysDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotKeysDescriptionMetadata.c(WebPivotKeysDescriptionMetadata.a);
            }
            if (a.k(WebPivotKeysDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPivotKeysDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotKeys");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Children", "String");
            a.item("Records", "String");
            a.item("Aggregations", "String");
            a.item("Level", "String");
            a.item("ColumnDimensionSeparator", "String");
            a.item("RowDimensionSeparator", "String");
        }
        static d(a) {
            WebPivotKeysDescriptionMetadata.b(a);
            a.ae("WebPivotKeys", () => new WebPivotKeysDescription());
            a.ad("WebPivotKeys", WebPivotKeysDescriptionMetadata.a);
        }
    }
    WebPivotKeysDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPivotKeysDescriptionMetadata, 'WebPivotKeysDescriptionMetadata');
    WebPivotKeysDescriptionMetadata.a = null;
    return WebPivotKeysDescriptionMetadata;
})();
